@@ -4,14 +4,14 @@ use namespace::autoclean;
 
 extends 'Weather::YR::Base';
 
-has 'language' => ( isa => 'Str', is => 'rw', default => 'nb' );
+has 'lang' => ( isa => 'Str', is => 'rw', default => 'nb' );
 
 has 'url' => ( isa => 'Str', is => 'ro', lazy_build => 1 );
 
 sub _build_url {
     my $self = shift;
 
-    return 'http://api.yr.no/weatherapi/textlocation/1.0/?latitude=' . $self->lat . ';longitude=' . $self->lon . ';language=' . $self->language;
+    return 'http://api.yr.no/weatherapi/textlocation/1.0/?latitude=' . $self->lat . ';longitude=' . $self->lon . ';language=' . $self->lang;
 }
 
 __PACKAGE__->meta->make_immutable;
